@@ -506,16 +506,25 @@ class DocHandler(LoginUrlMixin, BkDocHandler):
                 secret_key=self.application.secret_key,
                 signed=self.application.sign_sessions
             )
-            payload = get_token_payload(session.token)
-            payload.update(payload)
-            del payload['session_expiry']
+            extra_payload = get_token_payload(session.token)
+            extra_payload.update(payload)
+            del extra_payload['session_expiry']
             token = generate_jwt_token(
                 session_id,
                 secret_key=app.secret_key,
                 signed=app.sign_sessions,
                 expiration=app.session_token_expiration,
-                extra_payload=payload
+                extra_payload=extra_payload
             )
+            if config.reuse_sessions == 'warm':
+                state.execute(
+                    partial(
+                        self.application_context.create_session_if_needed,
+                        session_id,
+                        self.request,
+                        token
+                    )
+                )
         else:
             token = session.token
         logger.info(LOG_SESSION_CREATED, id(session.document))
@@ -893,7 +902,7 @@ def get_static_routes(static_dirs):
         if not os.path.isdir(path):
             raise ValueError(f"Cannot serve non-existent path {path}")
         patterns.append(
-            (rf"{slug}/(.*)", AuthenticatedStaticFileHandler, {"path": path})
+            (rf"{slug}/(.*)", AuthenticatedStaticFileHandler, {"path": path, "default_filename": "index.html"})
         )
     patterns.append((
         f'/{COMPONENT_PATH}(.*)', ComponentResourceHandler, {}
