@@ -103,14 +103,14 @@ export function model_getter(target: ReactiveESMView, name: string) {
       }
     }
   } else if (name === "on") {
-    return (prop: string | string[], callback: any) => {
+    return (prop: string | string[], callback: any, force: boolean = false) => {
       const props = isArray(prop) ? prop : [prop]
       for (let p of props) {
         if (p.startsWith("change:")) {
           p = p.slice("change:".length)
         }
         if (p in model.attributes || p.split(".")[0] in model.data.attributes) {
-          model.watch(target, p, callback)
+          model.watch(target, p, callback, force)
           continue
         } else if (p === "msg:custom") {
           target.on_event(callback)
@@ -555,6 +555,7 @@ export namespace ReactiveESM {
     data: p.Property<any>
     dev: p.Property<boolean>
     esm: p.Property<string>
+    events: p.Property<string[]>
     importmap: p.Property<any>
   }
 }
@@ -571,6 +572,7 @@ export class ReactiveESM extends HTMLBox {
   sucrase_transforms: Transform[] = ["typescript"]
   _destroyer: any | null = null
   _esm_watchers: any = {}
+  _event_callbacks: Map<(data: unknown) => void, (data: unknown) => void> = new Map()
 
   constructor(attrs?: Partial<ReactiveESM.Attrs>) {
     super(attrs)
@@ -591,7 +593,7 @@ export class ReactiveESM extends HTMLBox {
     this.connect(this.properties.importmap.change, () => this.recompile())
   }
 
-  watch(view: ReactiveESMView | null, prop: string, cb: any): void {
+  watch(view: ReactiveESMView | null, prop: string, cb: any, force: boolean = false): void {
     if (prop in this._esm_watchers) {
       this._esm_watchers[prop].push([view, cb])
     } else {
@@ -615,6 +617,18 @@ export class ReactiveESM extends HTMLBox {
       resolvedProp = propPath[propPath.length - 1]
     }
 
+    // Handle reset of param.Event properties
+    if (!force && target === this.data && resolvedProp && this.events.includes(resolvedProp)) {
+      const orig_cb = cb
+      cb = () => {
+        if (resolvedProp && this.data[resolvedProp]) {
+          orig_cb()
+          this.data.setv({[resolvedProp]: false})
+        }
+      }
+      this._event_callbacks.set(orig_cb, cb)
+    }
+
     // Attach watcher if property is found
     if (resolvedProp && target) {
       target.property(resolvedProp).change.connect(cb)
@@ -662,6 +676,11 @@ export class ReactiveESM extends HTMLBox {
       resolvedProp = propPath[propPath.length - 1]
     }
 
+    if (this._event_callbacks.has(cb)) {
+      cb = this._event_callbacks.get(cb)
+      this._event_callbacks.delete(cb)
+    }
+
     // Detach watcher if property is found
     if (resolvedProp && target) {
       return target.property(resolvedProp).change.disconnect(cb)
@@ -858,6 +877,7 @@ export default {render}`
       data:        [ Any                     ],
       dev:         [ Bool,             false ],
       esm:         [ Str,                 "" ],
+      events:      [ Array(Str),          [] ],
       importmap:   [ Any,                 {} ],
     }))
   }
